==> react-initial-props-2.10.0.tgz: package/lib/ssrComponentWithInitialProps.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { renderToNodeStream, renderToString } from 'react-dom/server';
import InitialPropsContext from './initialPropsContext';

var hrTimeToMs = function hrTimeToMs(diff) {
  return diff[0] * 1e3 + diff[1] * 1e-6;
};

export default function ssrComponentWithInitialProps(_ref) {
  var Target = _ref.Target,
      context = _ref.context,
      req = _ref.req,
      res = _ref.res,
      renderProps = _ref.renderProps,
      _ref$useStream = _ref.useStream,
      useStream = _ref$useStream === void 0 ? false : _ref$useStream;
  var startGetInitialProps = process.hrtime(); // get the page with the initialProps

  var pageComponent = renderProps.components[renderProps.components.length - 1]; // use the getInitialProps from the page to retrieve the props to initialize

  var getInitialProps = pageComponent.getInitialProps;
  return getInitialProps(context, req, res).then(function (initialProps) {
    var _renderResponse;

    var diffGetInitialProps = process.hrtime(startGetInitialProps); // Create App with Context with the initialProps

    var AppWithContext = /*#__PURE__*/React.createElement(InitialPropsContext.Provider, {
      value: {
        initialProps: initialProps
      }
    }, /*#__PURE__*/React.createElement(Target, Object.assign({}, renderProps, {
      initialProps: initialProps
    }))); // use a different action and response key depending if we're using streaming

    var _ref2 = useStream ? [renderToNodeStream, 'reactStream'] : [renderToString, 'reactString'],
        renderAction = _ref2[0],
        renderResponseKey = _ref2[1]; // start to calculate renderToString


    var startRenderToString = process.hrtime(); // render with the needed action

    var renderResponse = (_renderResponse = {}, _renderResponse[renderResponseKey] = renderAction(AppWithContext), _renderResponse); // calculate the difference of time used rendering

    var diffRenderToString = process.hrtime(startRenderToString); // return all the info

    return _extends(_extends({}, renderResponse), {}, {
      initialProps: initialProps,
      performance: {
        getInitialProps: hrTimeToMs(diffGetInitialProps),
        renderToString: hrTimeToMs(diffRenderToString)
      }
    });
  });
}

==> react-initial-props-2.11.0.tgz: package/lib/ssrComponentWithInitialProps.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { renderToNodeStream, renderToString } from 'react-dom/server';
import InitialPropsContext from './initialPropsContext';

var hrTimeToMs = function hrTimeToMs(diff) {
  return diff[0] * 1e3 + diff[1] * 1e-6;
};

export default function ssrComponentWithInitialProps(_ref) {
  var Target = _ref.Target,
      context = _ref.context,
      req = _ref.req,
      res = _ref.res,
      renderProps = _ref.renderProps,
      _ref$useStream = _ref.useStream,
      useStream = _ref$useStream === void 0 ? false : _ref$useStream;
  var startGetInitialProps = process.hrtime(); // get the page with the initialProps

  var pageComponent = renderProps.components[renderProps.components.length - 1]; // use the getInitialProps from the page to retrieve the props to initialize

  var getInitialProps = pageComponent.getInitialProps;
  return getInitialProps(context, req, res).then(function (initialProps) {
    var _renderResponse;

    var diffGetInitialProps = process.hrtime(startGetInitialProps); // Create App with Context with the initialProps

    var AppWithContext = /*#__PURE__*/React.createElement(InitialPropsContext.Provider, {
      value: {
        initialProps: initialProps
      }
    }, /*#__PURE__*/React.createElement(Target, Object.assign({}, renderProps, {
      initialProps: initialProps
    }))); // use a different action and response key depending if we're using streaming

    var _ref2 = useStream ? [renderToNodeStream, 'reactStream'] : [renderToString, 'reactString'],
        renderAction = _ref2[0],
        renderResponseKey = _ref2[1]; // start to calculate renderToString


    var startRenderToString = process.hrtime(); // render with the needed action

    var renderResponse = (_renderResponse = {}, _renderResponse[renderResponseKey] = renderAction(AppWithContext), _renderResponse); // calculate the difference of time used rendering

    var diffRenderToString = process.hrtime(startRenderToString); // return all the info

    return _extends({}, renderResponse, {
      initialProps: initialProps,
      performance: {
        getInitialProps: hrTimeToMs(diffGetInitialProps),
        renderToString: hrTimeToMs(diffRenderToString)
      }
    });
  });
}
